==> socat-1.3.0.0.tar.bz2: socat-1.3/sslcls.h <==
/* $Id: sslcls.h,v 1.2 2002/06/26 11:52:08 gerhard Exp $ */
/* Copyright Gerhard Rieger 2001, 2002 */
/* Published under the GNU General Public License V.2, see file COPYING */

#ifndef __sslcls_h_included
#define __sslcls_h_included 1

#if WITH_SYCLS
#if WITH_OPENSSL

void sycSSL_load_error_strings(void);
int sycSSL_library_init(void);
SSL_METHOD *sycSSLv2_client_method(void);
SSL_METHOD *sycSSLv3_client_method(void);
SSL_METHOD *sycSSLv23_client_method(void);
SSL_METHOD *sycTLSv1_client_method(void);
SSL_CTX *sycSSL_CTX_new(SSL_METHOD *method);
SSL *sycSSL_new(SSL_CTX *ctx);
int sycSSL_set_cipher_list(SSL *ssl, const char *str);
int sycSSL_set_fd(SSL *ssl, int fd);
int sycSSL_connect(SSL *ssl);
X509 *sycSSL_get_peer_certificate(SSL *ssl);

#endif /* WITH_OPENSSL */

#else /* !WITH_SYCLS */

#if WITH_OPENSSL

#define sycSSL_load_error_strings() SSL_load_error_strings()
#define sycSSL_library_init() SSL_library_init()
#define sycSSLv2_client_method() SSLv2_client_method()
#define sycSSLv3_client_method() SSLv3_client_method()
#define sycSSLv23_client_method() SSLv23_client_method()
#define sycTLSv1_client_method() TLSv1_client_method()
#define sycSSL_CTX_new(m) SSL_CTX_new(m)
#define sycSSL_new(c) SSL_new(c)
#define sycSSL_set_cipher_list(s,t) SSL_set_cipher_list(s,t)
#define sycSSL_set_fd(s,f) SSL_set_fd(s,f)
#define sycSSL_connect(s) SSL_connect(s)
#define sycSSL_get_peer_certificate(s)

#endif /* WITH_OPENSSL */

#endif /* !WITH_SYCLS */

#endif /* !defined(__sslcls_h_included) */

==> socat-1.3.1.0.tar.bz2: socat-1.3/sslcls.h <==
/* $Id: sslcls.h,v 1.3 2003/02/23 07:10:55 gerhard Exp $ */
/* Copyright Gerhard Rieger 2001-2003 */
/* Published under the GNU General Public License V.2, see file COPYING */

#ifndef __sslcls_h_included
#define __sslcls_h_included 1

#if WITH_SYCLS
#if WITH_OPENSSL

void sycSSL_load_error_strings(void);
int sycSSL_library_init(void);
SSL_METHOD *sycSSLv2_client_method(void);
SSL_METHOD *sycSSLv3_client_method(void);
SSL_METHOD *sycSSLv23_client_method(void);
SSL_METHOD *sycTLSv1_client_method(void);
SSL_CTX *sycSSL_CTX_new(SSL_METHOD *method);
SSL *sycSSL_new(SSL_CTX *ctx);
int sycSSL_set_cipher_list(SSL *ssl, const char *str);
int sycSSL_set_fd(SSL *ssl, int fd);
int sycSSL_connect(SSL *ssl);
int sycSSL_read(SSL *ssl, void *buf, int num);
int sycSSL_write(SSL *ssl, const void *buf, int num);
X509 *sycSSL_get_peer_certificate(SSL *ssl);
int sycSSL_shutdown(SSL *ssl);
void sycSSL_CTX_free(SSL_CTX *ctx);
void sycSSL_free(SSL *ssl);

#endif /* WITH_OPENSSL */

#else /* !WITH_SYCLS */

#if WITH_OPENSSL

#define sycSSL_load_error_strings() SSL_load_error_strings()
#define sycSSL_library_init() SSL_library_init()
#define sycSSLv2_client_method() SSLv2_client_method()
#define sycSSLv3_client_method() SSLv3_client_method()
#define sycSSLv23_client_method() SSLv23_client_method()
#define sycTLSv1_client_method() TLSv1_client_method()
#define sycSSL_CTX_new(m) SSL_CTX_new(m)
#define sycSSL_new(c) SSL_new(c)
#define sycSSL_set_cipher_list(s,t) SSL_set_cipher_list(s,t)
#define sycSSL_set_fd(s,f) SSL_set_fd(s,f)
#define sycSSL_connect(s) SSL_connect(s)
#define sycSSL_read(s,b,n) SSL_read(s,b,n)
#define sycSSL_write(s,b,n) SSL_write(s,b,n)
#define sycSSL_get_peer_certificate(s) SSL_get_peer_certificate(s)
#define sycSSL_shutdown(s) SSL_shutdown(s)
#define sycSSL_CTX_free(c) SSL_CTX_free(c)
#define sycSSL_free(s) SSL_free(s)

#endif /* WITH_OPENSSL */

#endif /* !WITH_SYCLS */

#endif /* !defined(__sslcls_h_included) */
